/*
	*
	* This file is a part of CoreFM.
	* A file manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/


#pragma once

#include "global.hpp"

#include "filesystemmodel.hpp"
#include "folderview.hpp"
#include "trashview.hpp"
#include "sideview.hpp"
#include "widgets.hpp"


typedef QList<FolderView*> Pages;

class CoreFM : public QMainWindow {

    Q_OBJECT

public:
    CoreFM( QString path = QDir::homePath() );

private:
    bool touchMode;
    bool showHidden;
    QString startupPath;
    bool showThumb;
    int viewMode;
    int zoomIconSize;

    void loadSettings();

    /* Create the UI */
    void startSetup();

    /* Create the address bar and toolbar */
    /* To be cleed in setupUI() */
    void createToolBar();

    /* Connections between @view1, @view2, @sideView and @addressBar */
    void makeConnections();

    /* Window Properties */
    void setWindowProperties();

    /* Current View */
    FolderView* currentView();

    QMenu* openWithMenu();
    FolderView *view1, *view2;
    SideView *sideView;
    AddressBar *addressBar;
    SizeRunner *mSzRunner;
    bool isSplit = false;

    /* Toolbar Actions */
    QAction *newFolderAct, *newFileAct, *showHiddenAct, *previewAct, *termAct;
    /* Toolbar and menu actions */
    QAction *cutAct, *copyAct, *pasteAct;
    /* Menu actions */
    QAction *openAct, *refreshAct, *selectAllAct, *renameAct, *trashAct, *deleteAct, *propsAct;
    QAction *batchRenameAct, *compressAct, *extractAct, *newWindowAct, *openWithAct;
    QAction *sortNameAct, *sortSizeAct, *sortDateAct, *sortOrderAct;
    /* Other actions */
    QAction *backAct, *upAct,/* *forwardAct,*/ *splitAct, *viewChangeAct, *treeWriteAct, *metadataAct, *searchAct;
    QAction *zoomInAct, *zoomOutAct;

    /* Move across the windows */
    static bool moveItems;

    QClipboard *clipBoard = QApplication::clipboard();
    CoreXdgMime *mimeHandler = CoreXdgMime::instance();

private Q_SLOTS:
    /* Create a new folder in the current view */
    void newFolder();
    void newFile();
    void toggleHidden();
    void togglePreviews();
    void openTerminal();
    void prepareMove();
    void prepareCopy();
    void paste();
    void refresh();
    void selectAll();
    void rename();
    void trashSelected();
    void deleteSelected();
    void showProperties();
    void compress();
    void extract();
    void goBack();
    void goForward();
    void goUp();
    void writeTree();
    void openSearch();
    void updateVarious();
    void newWindow( QString path = QDir::homePath() );
    void loadAddress( QString path = QDir::homePath() );
    void openInApp( QString path = QString() );
    void selectApp();
    void setSortType( QAction * );
    void setSortOrder();
    void contextMenu( const QPoint & );
    void zoomIn();
    void zoomOut();
    void showTrash();
    void toggleSplit();
    void nextView();
    void pinIt();
    void shareIt();
    void openMetadataViewer();
    void openRenamer();

Q_SIGNALS:
    void sizeCount( quint64, quint64, quint64 );
    void openNewTab( QString );
    void openNewWindow( QString );
    void updatePaste();
    void splitView();
    void changeView();
};
