/*
	*
	* This file is a part of CoreFM.
	* A file manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/


#pragma once

#include "global.hpp"


class SideView : public QWidget {

    Q_OBJECT

public :
    SideView( QWidget * );

private:
    bool touchMode;
    int sideviewSize;
    QSize sideviewIconSize;

    void createUI();

    QToolButton *title;
    QWidget *itemsWidget;
    QWidget *drivesWidget;
    QStackedWidget *stack;
    bool mCompact = false;

    StorageManager *sMgr;

private Q_SLOTS:
    void populateSideView();
    void repopulateDrives();
    void switchWidget();

    void toggleCompact();

protected:
    void paintEvent( QPaintEvent *pEvent );

Q_SIGNALS:
    void changeDir( QString );
    void showTrash();
    void pinIt();
    void shareIt();
	void toggleTools();
};

class SideViewItem : public QWidget {
	Q_OBJECT

public:
    SideViewItem( QString name, QIcon icon, QString target, bool drive, QWidget *parent );
    void setDevice( StorageBlock dev );
    void toggleWidth();

private:
    QString mName, mTarget;
    QIcon mIcon;
    bool mPressed, mHover, isDrive, mHoverMount;
    bool compact = false;
    QLabel *iconLbl, *textLbl;
    QVBoxLayout *itemsLyt, *drivesLyt;
    StorageBlock mDev;
    int mIconSize;

    QToolButton *mntBtn;

protected:
    void dragEnterEvent( QDragEnterEvent* );
    void dragMoveEvent( QDragMoveEvent* );
    void dropEvent( QDropEvent* );

    void mousePressEvent( QMouseEvent *mpEvent );
    void mouseReleaseEvent( QMouseEvent *mrEvent );

    void paintEvent( QPaintEvent *pEvent );

private Q_SLOTS:
    void toggleMount();

Q_SIGNALS:
    void clicked();
    void clicked( QString );
    void showTrash();
};
