/*
	*
	* This file is a part of CoreFM.
	* A file manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/


#include "widgets.hpp"


QFrame* separator() {

	QFrame *sep = new QFrame();
	sep->setFrameStyle( QFrame::VLine );

	return sep;
}

ActionButton::ActionButton( QWidget *parent ) : QToolButton( parent ) {

	setAutoRaise( true );
	setFocusPolicy( Qt::NoFocus );
    setIconSize( sm->value("CoreApps", "ToolBarIconSize") );
    setFixedSize( sm->value("CoreApps", "ToolBarIconSize") + QSize( 4, 4 ) );
};

void ActionButton::setDefaultAction( QAction *act ) {

	mDefAct = act;

	QToolButton::setDefaultAction( act );
	connect( act, &QAction::changed, this, &ActionButton::toggleVisible );
};

void ActionButton::toggleVisible() {

	if ( mDefAct->isVisible() )
		show();

	else
		hide();
};

AddressBar::AddressBar( QWidget *parent ) : QFrame( parent ) {

    toolBarHeight = QSize(sm->value("CoreApps", "ToolBarIconSize")).height() + 10;

	setFixedHeight( toolBarHeight );

	setFrameStyle( QFrame::NoFrame );

	setContentsMargins( QMargins( 2, 2, 2, 2 ) );
	setSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Fixed );

	backBtn = new ActionButton( this );
	upBtn = new ActionButton( this );
//	forwardBtn = new ActionButton( this );

	titleLbl = new QLabel();
	titleLbl->setFixedHeight( toolBarHeight );
	titleLbl->setContentsMargins( QMargins( 5, 0, 0, 0 ) );
	titleLbl->setAlignment( Qt::AlignVCenter | Qt::AlignLeft );
	titleLbl->setSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Fixed );

	sizeLbl = new QLabel();
	sizeLbl->setFixedHeight( toolBarHeight );
	sizeLbl->setContentsMargins( QMargins( 0, 0, 5, 0 ) );
	sizeLbl->setAlignment( Qt::AlignVCenter | Qt::AlignRight );
	sizeLbl->setSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Fixed );

	cutBtn = new ActionButton( this );
	copyBtn = new ActionButton( this );
	pasteBtn = new ActionButton( this );
	propsBtn = new ActionButton( this );
	findBtn = new ActionButton( this );
	selectAllBtn = new ActionButton( this );

	QHBoxLayout *addrLyt = new QHBoxLayout();
	addrLyt->setContentsMargins( QMargins() );
	addrLyt->setSpacing( 0 );

    addrLyt->addWidget( upBtn );
    addrLyt->addWidget( backBtn );
//	addrLyt->addWidget( forwardBtn );

	addrLyt->addWidget( titleLbl );
	addrLyt->addWidget( sizeLbl );

	addrLyt->addWidget( cutBtn );
	addrLyt->addWidget( copyBtn );
	addrLyt->addWidget( pasteBtn );
	addrLyt->addWidget( propsBtn );
	addrLyt->addWidget( findBtn );
	addrLyt->addWidget( selectAllBtn );

	freeSpaceLbl = new QLabel( this );
	freeSpaceLbl->setFixedHeight( toolBarHeight );
	freeSpaceLbl->setContentsMargins( QMargins( 5, 0, 0, 0 ) );

	toolsLayout = new QHBoxLayout();
	toolsLayout->setContentsMargins( QMargins() );
	toolsLayout->setSpacing( 0 );

	toolsLayout->addWidget( freeSpaceLbl );
	toolsLayout->addStretch();

	toolsWidget = new QWidget();
	toolsWidget->setLayout( toolsLayout );
	toolsWidget->hide();
	toolsWidget->setFixedHeight( toolBarHeight );

	QVBoxLayout *lyt = new QVBoxLayout();
	lyt->setContentsMargins( QMargins() );
	lyt->setSpacing( 0 );

	lyt->addLayout( addrLyt );
	lyt->addWidget( toolsWidget );

	setLayout( lyt );
};

void AddressBar::setText( QString txt ) {

//	QFontMetrics fm( titleLbl->font() );
//	if ( fm.boundingRect( txt ).width() > titleLbl->width() )
//		txt = QFileInfo(txt).fileName()fm.elidedText( CPrime::FileUtils::baseName( txt ), Qt::ElideRight, titleLbl->width() );

    titleLbl->setText( QFileInfo(txt).fileName() );
};

void AddressBar::setFreeSpace( QString txt ) {

	freeSpaceLbl->setText( txt );
};

void AddressBar::setBackAction( QAction *act ) {

	backBtn->setDefaultAction( act );
};

void AddressBar::setUpAction( QAction *act ) {

	upBtn->setDefaultAction( act );
};

//void AddressBar::setForwardAction( QAction *act ) {

//	forwardBtn->setDefaultAction( act );
//};

void AddressBar::setIOActions( QAction *cut, QAction *copy, QAction *paste ) {

	cutBtn->setDefaultAction( cut );
	copyBtn->setDefaultAction( copy );
	pasteBtn->setDefaultAction( paste );
};

void AddressBar::setPropsAction( QAction *act ) {

	propsBtn->setDefaultAction( act );
};

void AddressBar::setFindAction( QAction *act ) {

	findBtn->setDefaultAction( act );
};

void AddressBar::setSelectAllAction( QAction *act ) {

	selectAllBtn->setDefaultAction( act );
};

void AddressBar::addAction( QAction *act ) {

	ActionButton *btn = new ActionButton( this );
	btn->setDefaultAction( act );

	toolsLayout->addWidget( btn );
};

void AddressBar::setSize( quint64 files, quint64 folders, quint64 totalSize ) {

	QString contentsStr;

	/* Both files and folders */
	if( files and folders ) {
		if ( ( files == 1 ) and ( folders == 1 ) )
			contentsStr = QString( tr( "1 file, 1 sub-folder" ) );

		else if ( ( files > 1 ) and ( folders == 1 ) )
			contentsStr = QString( tr( "%1 files, 1 sub-folder" ) ).arg( files );

		else if ( ( files == 1 ) and ( folders > 1 ) )
			contentsStr = QString( tr( "1 file, %2 sub-folders" ) ).arg( folders );

		else
			contentsStr = QString( tr( "%1 files, %2 sub-folders" ) ).arg( files ).arg( folders );
	}

	/* Only files and no folders */
	else if ( files and !folders ) {
		if ( files == 1 )
			contentsStr = QString( tr( "%1 file" ) ).arg( files );

		else
			contentsStr = QString( tr( "%1 files" ) ).arg( files );
	}

	/* No files */
	else {
		/* No folders as well */
		if ( not folders )
			contentsStr = "Empty";

		/* One folder */
		else if ( folders == 1 )
			contentsStr = "1 sub-folder";

		/* n folders */
		else
			contentsStr = QString( tr( "%1 sub-folders" ) ).arg( folders );
	}

	sizeLbl->setText( contentsStr + QString( " (%1)" ).arg( CPrime::FileFunc::formatSize( totalSize ) ) );
};

void AddressBar::setSize( QString size ) {

	sizeLbl->setText( size );
};

void AddressBar::clearSize() {

	sizeLbl->clear();
};

void AddressBar::toggleTools() {

	if ( toolsWidget->isVisible() ) {
		toolsWidget->hide();
		setFixedHeight( toolBarHeight );
	}

	else {
		toolsWidget->show();
		setFixedHeight( toolBarHeight * 2 );
	}
};

void AddressBar::paintEvent( QPaintEvent *pEvent ) {

	QPainter painter( this );
	painter.setPen( Qt::NoPen );

    painter.setBrush( QColor( 0, 0, 0, 10 ) );
	painter.drawRect( rect() );

	painter.end();

	QFrame::paintEvent( pEvent );

	pEvent->accept();
};
