/*
	*
	* This file is a part of CoreFM.
	* A file manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/


#pragma once

#include "global.hpp"


class ActionButton : public QToolButton {

    Q_OBJECT

public:
    ActionButton( QWidget *parent );

public Q_SLOTS:
    void setDefaultAction( QAction * );

private:
    void toggleVisible();

    QAction *mDefAct;

};

class AddressBar : public QFrame {

    Q_OBJECT

public:
    AddressBar( QWidget *parent );
    void setText( QString );
    void setFreeSpace( QString );

    /* Permanent widgets of the first row */
    void setBackAction( QAction * );
    void setUpAction( QAction * );
//    void setForwardAction( QAction * );
    void setIOActions( QAction *, QAction *, QAction * );
    void setPropsAction( QAction * );
    void setFindAction( QAction * );
    void setSelectAllAction( QAction * );

    /* Dynamic actions of the second row */
    void addAction( QAction * );

private:
    QLabel *titleLbl;
    QLabel *sizeLbl;
    QLabel *freeSpaceLbl;
    ActionButton *backBtn, *upBtn/*, *forwardBtn*/;
    ActionButton *cutBtn, *copyBtn, *pasteBtn;
    ActionButton *propsBtn, *findBtn, *selectAllBtn;
    QWidget *toolsWidget;
    QHBoxLayout *toolsLayout;

    int toolBarHeight;

public Q_SLOTS:
    void setSize( quint64, quint64, quint64 );
    void clearSize();
    void setSize( QString );

private Q_SLOTS:
    void toggleTools();

protected:
	void paintEvent( QPaintEvent *pEvent );
};
